@@ -260,7 +260,7 @@ struct char_block {
   char_block   *next;
 
   char_block();
-  char_block::char_block(int length);
+  char_block(int length);
 };
 
 char_block::char_block()
