@@ -1,4 +1,4 @@
-/* Last non-groff version: main.cc 1.23  (Berkeley)  85/08/05
+/* Last non-groff version: main.c 1.23  (Berkeley)  85/08/05
  *
  * Adapted to GNU troff by Daniel Senderowicz 99/12/29.
  *
@@ -90,13 +90,27 @@ extern void HGPrintElt(ELT *element, int baseline);
 extern ELT *DBInit();
 extern ELT *DBRead(register FILE *file);
 extern POINT *PTInit();
-extern POINT *PTMakePoint(float x, float y, POINT **pplist);
+extern POINT *PTMakePoint(double x, double y, POINT **pplist);
 
 
 #define SUN_SCALEFACTOR 0.70
 
 /* #define DEFSTIPPLE    "gs" */
 #define DEFSTIPPLE	"cf"
+/*
+ * This grn implementation emits `.st' requests to control stipple effects,
+ * but groff does not (currently) support any such request.
+ *
+ * This hack disables the emission of such requests, without destroying the
+ * infrastructure necessary to support the feature in the future; to enable
+ * the emission of `.st' requests, at a future date when groff can support
+ * them, simply rewrite the following #define as:
+ *
+ *   #define USE_ST_REQUEST  stipple
+ *
+ * with accompanying comment: ``emit `.st' requests as required''.
+ */
+#define USE_ST_REQUEST  0	/* never emit `.st' requests */
 
 #define MAXINLINE	100	/* input line length */
 
@@ -125,7 +139,7 @@ int lastyline;			/* A line's vertical position is NOT the  */
 /* `default' command and are reset each time the    */
 /* start of a picture (.GS) is found.               */
 
-char *deffont[] =
+const char *deffont[] =
 {"R", "I", "B", "S"};
 int defsize[] =
 {10, 16, 24, 36};
@@ -160,7 +174,7 @@ int style[STYLES] =
 double scale = 1.0;		/* no scaling, default */
 int defpoint = 0;		/* flag for pointsize scaling */
 char *defstipple = (char *) 0;
-enum {
+enum E {
   OUTLINE, FILL, BOTH
 } polyfill;
 
@@ -205,16 +219,16 @@ int linenum = 0;		/* line number of input file */
 char inputline[MAXINLINE];	/* spot to filter through the file */
 char *c1 = inputline;		/* c1, c2, and c3 will be used to */
 char *c2 = inputline + 1;	/* hunt for lines that begin with */
-char *c3 = inputline + 2;	/* ".GS" by looking individually */
+char *c3 = inputline + 2;	/* `.GS' by looking individually */
 char *c4 = inputline + 3;	/* needed for compatibility mode */
-char GScommand[MAXINLINE];	/* put user's ".GS" command line here */
+char GScommand[MAXINLINE];	/* put user's `.GS' command line here */
 char gremlinfile[MAXINLINE];	/* filename to use for a picture */
 int SUNFILE = FALSE;		/* TRUE if SUN gremlin file */
 int compatibility_flag = FALSE;	/* TRUE if in compatibility mode */
 
 
 void getres();
-char *doinput(FILE *fp);
+int doinput(FILE *fp);
 void conv(register FILE *fp, int baseline);
 void savestate();
 int has_polygon(register ELT *elist);
@@ -316,7 +330,7 @@ main(int argc,
     } else
       fp = stdin;
 
-    while (doinput(fp) != NULL) {
+    while (doinput(fp)) {
       if (*c1 == '.' && *c2 == 'G' && *c3 == 'S') {
 	if (compatibility_flag ||
 	    *c4 == '\n' || *c4 == ' ' || *c4 == '\0')
@@ -327,6 +341,8 @@ main(int argc,
 	fputs(inputline, stdout);
     }
   }
+
+  return 0;
 }
 
 
@@ -388,7 +404,7 @@ getres()
 
 
 /*----------------------------------------------------------------------------*
- | Routine:	char  * doinput (file_pointer)
+ | Routine:	int  doinput (file_pointer)
  |
  | Results:	A line of input is read into `inputline'.
  |
@@ -398,16 +414,14 @@ getres()
  |		updating `linenum'.
  *----------------------------------------------------------------------------*/
 
-char *
+int
 doinput(FILE *fp)
 {
-  char *k;
-
-  if ((k = fgets(inputline, MAXINLINE, fp)) == NULL)
-    return k;
+  if (fgets(inputline, MAXINLINE, fp) == NULL)
+    return 0;
   if (strchr(inputline, '\n'))	/* ++ only if it's a complete line */
     linenum++;
-  return (char *) !NULL;
+  return 1;
 }
 
 
@@ -429,7 +443,7 @@ initpic()
     thick[i] = defthick[i];
   }
   for (i = 0; i < FONTS; i++) {		/* font name defaults */
-    tfont[i] = deffont[i];
+    tfont[i] = (char *)deffont[i];
   }
   for (i = 0; i < SIZES; i++) {		/* font size defaults */
     tsize[i] = defsize[i];
@@ -487,7 +501,7 @@ conv(register FILE *fp,
   strcpy(GScommand, inputline);	/* save `.GS' line for later */
 
   do {
-    done = (doinput(fp) == NULL);	/* test for EOF */
+    done = !doinput(fp);		/* test for EOF */
     flyback = (*c3 == 'F');		/* and .GE or .GF */
     compat = (compatibility_flag ||
 	      *c4 == '\n' || *c4 == ' ' || *c4 == '\0');
@@ -517,7 +531,7 @@ conv(register FILE *fp,
 
       if (stipple == (char *) NULL)	/* if user forgot stipple    */
 	if (has_polygon(PICTURE))	/* and picture has a polygon */
-	  stipple = DEFSTIPPLE;		/* then set the default      */
+	  stipple = (char *)DEFSTIPPLE;		/* then set the default      */
 
       if ((temp = bottompoint - toppoint) < 0.1)
 	temp = 0.1;
@@ -565,7 +579,7 @@ conv(register FILE *fp,
 	     ".sp -1\n",
 	     xright - xleft, ybottom - ytop, GScommand);
 
-      if (stipple)		/* stipple requested for this picture */
+      if (USE_ST_REQUEST)	/* stipple requested for this picture */
 	printf(".st %s\n", stipple);
       lastx = xleft;		/* note where we are (upper left */
       lastyline = lasty = ytop;	/* corner of the picture)        */
@@ -631,7 +645,7 @@ conv(register FILE *fp,
       printf("\\D't %du'\n", DEFTHICK);
       if (flyback)		/* make sure we end up at top of */
 	printf(".sp -1\n");	/* picture if `flying back'      */
-      if (stipple)		/* restore stipple to previous */
+      if (USE_ST_REQUEST)	/* restore stipple to previous */
 	printf(".st\n");
       printf(".br\n"
 	     ".ft \\n(g3\n"
@@ -685,8 +699,8 @@ savestate()
  *----------------------------------------------------------------------------*/
 
 void
-savebounds(float x,
-	   float y)
+savebounds(double x,
+	   double y)
 {
   if (x < leftpoint)
     leftpoint = x;
@@ -780,17 +794,17 @@ interpret(char *line)
 
   case 'l':			/* l */
     if (isdigit(str1[1])) {	/* set stipple index */
-      int index = atoi(str1 + 1), val;
+      int idx = atoi(str1 + 1), val;
 
-      if (index < 0 || index > NSTIPPLES) {
-	error("bad stipple number %1 at line %2", index, linenum);
+      if (idx < 0 || idx > NSTIPPLES) {
+	error("bad stipple number %1 at line %2", idx, linenum);
 	break;
       }
       if (!defstipple_index)
 	defstipple_index = other_stipple_index;
       val = atoi(str2);
       if (val >= 0 && val < 256)
-	stipple_index[index] = val;
+	stipple_index[idx] = val;
       else
 	error("bad stipple index value at line %1", linenum);
       break;
